aboutsummaryrefslogtreecommitdiff
path: root/isa/x-symbol-isabelle.el
diff options
context:
space:
mode:
Diffstat (limited to 'isa/x-symbol-isabelle.el')
-rw-r--r--isa/x-symbol-isabelle.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/isa/x-symbol-isabelle.el b/isa/x-symbol-isabelle.el
index f4ee80dd..eb6facb7 100644
--- a/isa/x-symbol-isabelle.el
+++ b/isa/x-symbol-isabelle.el
@@ -110,10 +110,10 @@ or subscript tag."
:type 'regexp)
;; the [\350-\360].\350 part is there to enable single char sub/super scripts
;; with coloured Isabelle output.
(defcustom x-symbol-isabelle-single-char-regexp
- "[\350-\360].\350\\|[^\\]\\|\\\\\\\\?<[A-Za-z0-9_']+>"
+ "[\350-\357].\350\\|\^A[A-H].\^AA\\|[^\\]\\|\\\\\\\\?<[A-Za-z0-9_']+>"
"Return regexp matching \<ident> or c for some char c."
:group 'x-symbol-isabelle
:type 'regexp)
@@ -110,10 +110,10 @@ or subscript tag."
:type 'regexp)
-;; the [\350-\360].\350 part is there to enable single char sub/super scripts
-;; with coloured Isabelle output.
+;; the [\350-\357].\350\\|\^A[A-H].\^AA part is there to enable single
+;; char sub/super scripts with coloured Isabelle output.
(defcustom x-symbol-isabelle-single-char-regexp